/******************************************************************************
*                                                                             *
*  File:                          main.c                                      *
*  Project:                      Project 3                                    *
*                                                                             *
*  Description: This file contains C code for a PIC16F690 using HiTech PICC   *
*               lite compiler written for the PICkit2 Low Pin Count Demo	  *
*				board.														  *
*				The project simply alternates flashing the RC0/DS1 and        *
*				RC1/DS2 LEDs at a 500 msec rate. This project also	      	  *
*				demonstrates how to use a Function.                           *
*                                                                             *
*******************************************************************************
*                                                                             *
*  Created By:  Chuck Hellebuyck 10/18/06                                     *
*                                                                             *
*  Versions:                                                                  *
*                                                                             *
*  MAJ.MIN - AUTHOR - CHANGE DESCRIPTION                                      *
*                                                                             *
*   1.0    - T.R.S. - Alternate Flash RC0 and RC1 with 500 msec on/off time   *
*                                                                             *
******************************************************************************/
#define _LEGACY_HEADERS //Added for compiler versions 9.81+
#include <pic.h>		// Include HITECH CC header file

/*
PIC16F690 Configuration
*/
__CONFIG (INTIO & WDTDIS & PWRTDIS & MCLRDIS & BORDIS & UNPROTECT & IESODIS & FCMDIS ); //Internal clock, Watchdog off, MCLR off, Code Unprotected

void pause( unsigned short usvalue );		//Establish pause routine function
void msecbase( void );						//Establish millisecond base function

main()
{
ANSEL =	0;				// Intialize A/D ports off
CM1CON0 = 0;			// Initialize Comparator 1 off
CM2CON0 = 0;			// Initialize Comparator 2 off

PORTC = 0x00;			//Clear PortC port
TRISC = 0x00;			//All PortC I/O outputs
 

while(1==1)				//loop forever
	{
		RC0 = 1;         	// Turn on RC0 LED 
		RC1 = 0;			// Turn off RC1 LED
		pause(500);       	// Delay for .5 seconds

		RC0 = 0;       		// Turn off RC0 LED 
		RC1 = 1;			// Turn on RC1 LED
    	pause(500);       	// Delay for .5 seconds
		
	}	//End while

}	//end main


//*******************************************************
//pause - multiple millisecond delay routine
//*******************************************************

void pause( unsigned short usvalue )
{
	unsigned short x;
	
	for (x=0; x<=usvalue; x++)	//Loop through a delay equal to usvalue
		{						// in milliseconds.
		msecbase();				//Jump to millisec delay routine
		}
}


/********************************************************
* msecbase - 1 msec pause routine						*
* The Internal oscillator is set to 4 Mhz and the		*
* internal instruction clock is 1/4 of the oscillator.	*
* This makes the internal instruction clock 1 Mhz or	*
* 1 usec per clock pulse.								*
* Using the 1:4 prescaler on the clock input to Timer0	* 
* slows the Timer0 count increment to 1 count/4 usec.	*
* Therefore 250 counts of the Timer0 would make a one	*
* millisecond delay (250 * 4 usec). But there are other	*
* instructions in the delay loop so using the MPLAB 	*
* stopwatch we find that we need Timer0 to overflow at 	*
* 243 clock ticks. Preset Timer0 to 13 (0D hex) to make	*
* Timer0 overflow at 243 clock ticks (256-13 = 243).	*
* This results in a 1.001 millisecond delay which is 	*
* close enough.											*
*********************************************************/

void msecbase(void)
{
	OPTION = 0b00000001;		//Set prescaler to TMRO 1:4
	TMR0 = 0xD;					//Preset TMRO to overflow on 250 counts
	while(!T0IF);				//Stay until TMRO overflow flag equals 1
	T0IF = 0;					//Clear the TMR0 overflow flag
}
