/******************************************************************************
*                                                                             *
*  File:                          main.c                                      *
*  Project:                      Project 4                                    *
*                                                                             *
*  Description: This file contains C code for a PIC16F690 using HiTech PICC   *
*               compiler version 9.60. The code is written for the PICkit2	  *
* 				low pin count demo board.									  *
*				The project scrolls thru the RC0/DS1 to RC3/DS4 LEDs using	  *
*				the For	statement and a 500 msec delay Function. 			  *
*				                                                              *
*                                                                             *
*  Created By:  Chuck Hellebuyck 10/18/06                                     *
*                                                                             *
*  Versions:                                                                  *
*                                                                             *
*  MAJ.MIN - AUTHOR - CHANGE DESCRIPTION                                      *
*                                                                             *
*   1.0    - T.R.S. - Scroll thru RC0/DS1 thru RC3/DS4 with 500 msec		  *
*					  on/off time	  										  *
*                                                                             *
******************************************************************************/
#define _LEGACY_HEADERS //Added for compiler versions 9.81+
#include <pic.h>		// Include HITECH CC header file

/*
PIC16F690 Configuration
*/
__CONFIG (INTIO & WDTDIS & PWRTDIS & MCLRDIS & BORDIS & UNPROTECT & IESODIS & FCMDIS ); //Internal clock, Watchdog off, MCLR off, Code Unprotected

unsigned short delay=500;			//Initialize on/off delay value to 500 msec

void Pause( unsigned short msvalue );		//Establish pause routine function
void msecbase( void );				//Establish millisecond base function

main()
{
ANSEL =	0;				// Intialize A/D ports off
CM1CON0 = 0;			// Initialize Comparator 1 off
CM2CON0 = 0;			// Initialize Coparator 2 off

PORTC = 0x00;			//Clear PortC port
TRISC = 0x00;			//All PortC I/O outputs

while(1==1)				//loop forever
	{
	int x;
	for(x=1; x<9; x=x*2)
		{
		PORTC = x;         		// Turn on next LED 
		Pause(delay);       	// Delay for .5 seconds
		}	// End For
	}	//End while
}	//end main


//*******************************************************
//pause - multiple millisecond delay routine
//*******************************************************

void Pause( unsigned short msvalue )
{
	unsigned short x;
	
	for (x=0; x<=msvalue; x++)	//Loop through a delay equal to msvalue
		{				// in milliseconds.
		msecbase();		//Jump to millisec delay routine
		}
}


//*******************************************************
//msecbase - 1 msec pause routine
//*******************************************************

void msecbase(void)
{
	OPTION = 0b00000001;		//Set prescaler to TMRO 1:4
	TMR0 = 0xd;			//Preset TMRO to overflow on 250 counts
	while(!T0IF);			//Stay until TMRO overflow flag equals 1
	T0IF = 0;			//Clear the TMR0 overflow flag
}
