/******************************************************************************
*                                                                             *
*  File:                          Proj7.C                         			  *
*                                                                             *
*  Description: This file contains C code for a PIC16F690 using HiTech PICC   *
*               lite compiler version 9.60 written for the PICkit2 Demo Board.*
*				The project lights the LEDs in sequence as the switch 		  *
*				SW1-RA3 switch is pressed. This program uses the Switch-Case  *
*				command to control which LEDs to light.						  *
*				This program also uses linking to include a debounce delay.	  *
*******************************************************************************
*                                                                             *
*  Created By:  Chuck Hellebuyck 7/12/07                                      *
*                                                                             *
*  Versions:                                                                  *
*                                                                             *
*  MAJ.MIN - AUTHOR - CHANGE DESCRIPTION                                      *
*                                                                             *
*   1.0    - T.R.S. - Sequence thru LEDs when switch S3 on RA3 is pressed     *
*                                                                             *
******************************************************************************/
#define _LEGACY_HEADERS //Added for compiler versions 9.81+
#include <pic.h>			// Include HITECH CC header file
#include "pause.h"			// Include Pause Function Header

#define SW1	 	RA3			// Create nickname for RA3 port

/*
PIC16F690 Configuration
*/
__CONFIG (INTIO & WDTDIS & PWRTDIS & MCLRDIS & BORDIS & UNPROTECT & IESODIS & FCMDIS ); //Internal clock, Watchdog off, MCLR off, Code Unprotected


main()
{
unsigned char state_led = 0; 	//Create 8 bit variable to store switch count

ANSEL =	0;				// Intialize A/D ports off
CM1CON0 = 0;			// Initialize Comparator 1 off
CM2CON0 = 0;			// Initialize Comparator 2 off

PORTC = 0x00;			//Clear PortC port
TRISC = 0x00;			//All PortC I/O outputs
TRISA = 0xFF;			//All PortA I/O inputs


while(1==1)				//loop forever
{

if (SW1 == 0)			// if a button press is detected,
 	{					
	state_led++;		//  increment the LED state variable
	switch (state_led)
		 {
			case 1:					// STATE0: turn only the D0 LED on
				RC0 = 1;
				RC1 = 0;
				RC2 = 0;
				RC3 = 0;
				break;
			case 2:					// STATE1: turn only the D1 LED on
				RC0 = 0;
				RC1 = 1;
				RC2 = 0;
				RC3 = 0;
				break;
			case 3:					// STATE2: turn only the D2 LED on
				RC0 = 0;
				RC1 = 0;
				RC2 = 1;
				RC3 = 0;
				break;
			case 4:					// STATE3: turn only the D3 LED on
				RC0 = 0;
				RC1 = 0;
				RC2 = 0;
				RC3 = 1;
				break;
			default:				// If state_led > 3 reset switch count to zero
				state_led = 0;		// All LEDs off	
				RC0 = 0;
				RC1 = 0;
				RC2 = 0;
				RC3 = 0;				
				break;
			} //end switch
		while (!SW1);				// Hold here until switch is released
		pause (10);					// Delay 10 milliseconds and check again
		while (!SW1);				// For simple debounce of switch
	} //End If
}	//End while
}	//end main
