/******************************************************************************
*                                                                             *
*  File:                          main.c                         			  *
*  Project:                      Project 8                                    *
*                                                                             *
*  Description: This file contains C code for a PIC16F690 using HiTech PICC   *
*               lite compiler version 9.60 written for the PICkit2 Demo Board.*
*				The project lights the LEDs in sequence as the potentiometer  *
*				is turned. This program uses the PIC16F690 A/D port RA0		  *
*				to read the potentiometer value and then compares the value	  *
*				using a series of IF commands to test the value against 	  *
*				preset constants to determine which LEDs to light.	  		  *
*******************************************************************************
*                                                                             *
*  Created By:  Chuck Hellebuyck 7/12/07                                      *
*                                                                             *
*  Versions:                                                                  *
*                                                                             *
*  MAJ.MIN - AUTHOR - CHANGE DESCRIPTION                                      *
*                                                                             *
*   1.0    - T.R.S. - Sequence thru LEDs when switch S3 on RA3 is pressed 
*
*   2.0    - I improved this over the code printed in the book so the LED
*		setup is slightly different and so is IF statement order.                                                                             *
******************************************************************************/
#define _LEGACY_HEADERS //Added for compiler versions 9.81+
#include <pic.h>

/*
*/
__CONFIG(INTIO & WDTDIS & PWRTEN & MCLRDIS & UNPROTECT & UNPROTECT & BORDIS & IESODIS & FCMDIS);

#define DS1_on 0b00000001;			//Create nickname to light DS1 LED
#define DS2_on 0b00000011;			//Create nickname to light DS1,2 LED
#define DS3_on 0b00000111;			//Create nickname to light DS1,2,3 LED
#define DS4_on 0b00001111;			//Create nickname to light DS1,2,3,4 LED
	
//Alternative way to define DS1 through DS4 using const directive
//const DS1_on 0b00000001;			//Create nickname to light DS1 LED
//const DS2_on 0b00000011;			//Create nickname to light DS1,2 LED
//const DS3_on 0b00000111;			//Create nickname to light DS1,2,3 LED
//const DS4_on 0b00001111;			//Create nickname to light DS1,2,3,4 LED

int advalue = 0;					//Create A/D storage value and clear it

main()
{
PORTA = 0;				//Clear PortA
TRISA = 0xFF;			//All PortA I/O inputs
CM1CON0 = 0;			//C1 Comparator off
ANSEL = 1;				//A/D module on
ADCON0 = 0b00000001;	//AtoD on, Left justified, Channel AN0/RA0 selected
ADCON1 = 0b00111000;	//Internal RC clock for A/D conversion
PORTC = 0;				//Clear PortC
TRISC = 0; 				//All PortC is output

while(1==1)				//Loop Forever
{
GODONE = 1;	//Start A/D process
	while (GODONE ==1)	//wait for A/D to finish
	{
	}
	
advalue = ADRESH;		//Store A/D result in variable ADVALUE

	if (advalue >30)	//Test if A/D value is less than 60 decimal
	{
	PORTC = DS1_on;		//Less than 60, light DS1 LED
	//RC3 = 1;
	}
	if (advalue >90)	//Test if A/D value less than 120 decimal
	{
	PORTC = DS2_on;		//Less than 120, light DS1,2 LEDs
	//RC2 = 1;
	}
	if (advalue >150)	//Test if A/D value less than 180
	{
	PORTC = DS3_on;		//Less than 180, light DS1,2,3 LEDs
	//RC1 = 1;
	}
	if (advalue > 210)	//Test if A/D value less than 240
	{
	PORTC = DS4_on;		//Less than 240, light DS1,2,3,4 LEDs
	//RC0 = 1;
	}
	if (advalue <= 30)	//Test if A/D value equal to or greater than 240
	{
	PORTC = 0;			//Set all LEDs off
	}
}	//End While
}	//End Main
